# TrustedCertificateBundleStatus

The Status for a TrustedCertificateBundle. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**trusted_certs** | [**[TrustedCertificate]**](TrustedCertificate.md) | List of TrustedCertificate | [optional] 
**trusted_certs_etag** | **str** | The entity tag (etag) associated with trusted_certs. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


